English \| `简体中文 <README-CN.md>`__

|image0|

AlibabaCloud DKMS-GCS SDK for Python
------------------------------------

-  `Overview <https://www.alibabacloud.com/help/doc-detail/311016.htm>`__
-  `Quick
   Start <https://www.alibabacloud.com/help/doc-detail/311368.htm>`__
-  `Sample Code </example>`__

Requirements
------------

-  Python 2.7.15 or later

Install
-------

::

   pip install alibabacloud-dkms-gcs-python2

License
-------

`Apache-2.0 <http://www.apache.org/licenses/LICENSE-2.0>`__

Copyright (c) 2009-present, Alibaba Cloud All rights reserved.

.. |image0| image:: https://aliyunsdk-pages.alicdn.com/icons/AlibabaCloud.svg
